Learn R Programming

ingres (version 1.0.0)

produceNetworkForCluster: Produce a tidygraph network for a given cluster

Description

Produce a tidygraph network for a given cluster

Usage

produceNetworkForCluster(ingres.object, cluster.id)

Value

A tidygraph object containing the network for the given cluster.

Arguments

ingres.object

The ingres object containing the relevant data.

cluster.id

The id of the cluster for which the network is to be produced.

Examples

Run this code
# Create an ingres object with viper slot
ing = createIngresObjectFromSeurat(
  small_blca_wang, "RNA", "data", network_genes, network
)
ing@viper = viper_results

ing = computePbnByCluster(ing)

network = produceNetworkForCluster(ing, "1")
print(network)

Run the code above in your browser using DataLab