Learn R Programming

ingres (version 1.0.0)

computePbnByCluster: Compute a Probabilistic Boolean Network (PBN) for each cluster or each cell

Description

After running performViper, this can be run to produce a PBN with the identity function probability for each node relative to the VIPER normalised enrichment score (NES) for cell. For computePbnByCluster, the median NES for all cells in that cluster will be used.

Usage

computePbnByCluster(ingres.object, range = c(-1, 1))

computePbnBySingleCell(ingres.object, range = c(-1, 1))

Value

An ingres object with the cluster.pbn or the single.cell.pbn slot filled

Arguments

ingres.object

An ingres object with a non-null VIPER slot.

range

A vector representing the range to which the NES are to be re-scaled. range[1]+range[2] == 0 should be TRUE. Defaults to [-1, 1]

Functions

  • computePbnByCluster: Compute a Probabilistic Boolean Network (PBN) for each cluster

  • computePbnBySingleCell: Compute a Probabilistic Boolean Network (PBN) for each cell

Examples

Run this code
# Create an ingres object with viper slot
ing = createIngresObjectFromSeurat(
  small_blca_wang, "RNA", "data", network_genes, network
)
ing@viper = viper_results

ing = computePbnByCluster(ing)
head(ing@cluster.pbn)

ing = computePbnBySingleCell(ing)
head(ing@single.cell.pbn)

# Restrict range to (-0.5, 0.5)
ing = computePbnByCluster(ing, range = c(-0.5, 0.5))
head(ing@cluster.pbn)

ing = computePbnBySingleCell(ing, range = c(-0.5, 0.5))
head(ing@single.cell.pbn)

Run the code above in your browser using DataLab